aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/Tango.PMR/Debugging
diff options
context:
space:
mode:
authorRoy Ben-Shabat <Roy@Twine-s.com>2018-05-06 13:50:14 +0300
committerRoy Ben-Shabat <Roy@Twine-s.com>2018-05-06 13:50:14 +0300
commitc14073e78d2c5b9569f91f47609d431da48ba706 (patch)
tree1498d47e10c6e97d28c3f45f5f9ac57276801a98 /Software/Visual_Studio/Tango.PMR/Debugging
parent551ca57984c369ce6084a612c8def44e2dbc3cc8 (diff)
downloadTango-c14073e78d2c5b9569f91f47609d431da48ba706.tar.gz
Tango-c14073e78d2c5b9569f91f47609d431da48ba706.zip
Added start/stop diagnostics and debugging on PMR.
Added device info to connected machine view. Added enable/disable diagnostics/debugging to connected machine view. Improved transfer rate calculation.
Diffstat (limited to 'Software/Visual_Studio/Tango.PMR/Debugging')
-rw-r--r--Software/Visual_Studio/Tango.PMR/Debugging/StartDebugLogRequest.cs131
-rw-r--r--Software/Visual_Studio/Tango.PMR/Debugging/StartDebugLogResponse.cs (renamed from Software/Visual_Studio/Tango.PMR/Debugging/DebugLogResponse.cs)48
-rw-r--r--Software/Visual_Studio/Tango.PMR/Debugging/StopDebugLogRequest.cs (renamed from Software/Visual_Studio/Tango.PMR/Debugging/DebugLogRequest.cs)40
-rw-r--r--Software/Visual_Studio/Tango.PMR/Debugging/StopDebugLogResponse.cs131
4 files changed, 306 insertions, 44 deletions
diff --git a/Software/Visual_Studio/Tango.PMR/Debugging/StartDebugLogRequest.cs b/Software/Visual_Studio/Tango.PMR/Debugging/StartDebugLogRequest.cs
new file mode 100644
index 000000000..a6f00805b
--- /dev/null
+++ b/Software/Visual_Studio/Tango.PMR/Debugging/StartDebugLogRequest.cs
@@ -0,0 +1,131 @@
+// Generated by the protocol buffer compiler. DO NOT EDIT!
+// source: StartDebugLogRequest.proto
+#pragma warning disable 1591, 0612, 3021
+#region Designer generated code
+
+using pb = global::Google.Protobuf;
+using pbc = global::Google.Protobuf.Collections;
+using pbr = global::Google.Protobuf.Reflection;
+using scg = global::System.Collections.Generic;
+namespace Tango.PMR.Debugging {
+
+ /// <summary>Holder for reflection information generated from StartDebugLogRequest.proto</summary>
+ public static partial class StartDebugLogRequestReflection {
+
+ #region Descriptor
+ /// <summary>File descriptor for StartDebugLogRequest.proto</summary>
+ public static pbr::FileDescriptor Descriptor {
+ get { return descriptor; }
+ }
+ private static pbr::FileDescriptor descriptor;
+
+ static StartDebugLogRequestReflection() {
+ byte[] descriptorData = global::System.Convert.FromBase64String(
+ string.Concat(
+ "ChpTdGFydERlYnVnTG9nUmVxdWVzdC5wcm90bxITVGFuZ28uUE1SLkRlYnVn",
+ "Z2luZyIWChRTdGFydERlYnVnTG9nUmVxdWVzdEIfCh1jb20udHdpbmUudGFu",
+ "Z28ucG1yLmRlYnVnZ2luZ2IGcHJvdG8z"));
+ descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
+ new pbr::FileDescriptor[] { },
+ new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Debugging.StartDebugLogRequest), global::Tango.PMR.Debugging.StartDebugLogRequest.Parser, null, null, null, null)
+ }));
+ }
+ #endregion
+
+ }
+ #region Messages
+ public sealed partial class StartDebugLogRequest : pb::IMessage<StartDebugLogRequest> {
+ private static readonly pb::MessageParser<StartDebugLogRequest> _parser = new pb::MessageParser<StartDebugLogRequest>(() => new StartDebugLogRequest());
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pb::MessageParser<StartDebugLogRequest> Parser { get { return _parser; } }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pbr::MessageDescriptor Descriptor {
+ get { return global::Tango.PMR.Debugging.StartDebugLogRequestReflection.Descriptor.MessageTypes[0]; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ pbr::MessageDescriptor pb::IMessage.Descriptor {
+ get { return Descriptor; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StartDebugLogRequest() {
+ OnConstruction();
+ }
+
+ partial void OnConstruction();
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StartDebugLogRequest(StartDebugLogRequest other) : this() {
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StartDebugLogRequest Clone() {
+ return new StartDebugLogRequest(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override bool Equals(object other) {
+ return Equals(other as StartDebugLogRequest);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public bool Equals(StartDebugLogRequest other) {
+ if (ReferenceEquals(other, null)) {
+ return false;
+ }
+ if (ReferenceEquals(other, this)) {
+ return true;
+ }
+ return true;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override int GetHashCode() {
+ int hash = 1;
+ return hash;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override string ToString() {
+ return pb::JsonFormatter.ToDiagnosticString(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void WriteTo(pb::CodedOutputStream output) {
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public int CalculateSize() {
+ int size = 0;
+ return size;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(StartDebugLogRequest other) {
+ if (other == null) {
+ return;
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(pb::CodedInputStream input) {
+ uint tag;
+ while ((tag = input.ReadTag()) != 0) {
+ switch(tag) {
+ default:
+ input.SkipLastField();
+ break;
+ }
+ }
+ }
+
+ }
+
+ #endregion
+
+}
+
+#endregion Designer generated code
diff --git a/Software/Visual_Studio/Tango.PMR/Debugging/StopDebugLogResponse.cs b/Software/Visual_Studio/Tango.PMR/Debugging/StopDebugLogResponse.cs
new file mode 100644
index 000000000..a3b7adaab
--- /dev/null
+++ b/Software/Visual_Studio/Tango.PMR/Debugging/StopDebugLogResponse.cs
@@ -0,0 +1,131 @@
+// Generated by the protocol buffer compiler. DO NOT EDIT!
+// source: StopDebugLogResponse.proto
+#pragma warning disable 1591, 0612, 3021
+#region Designer generated code
+
+using pb = global::Google.Protobuf;
+using pbc = global::Google.Protobuf.Collections;
+using pbr = global::Google.Protobuf.Reflection;
+using scg = global::System.Collections.Generic;
+namespace Tango.PMR.Debugging {
+
+ /// <summary>Holder for reflection information generated from StopDebugLogResponse.proto</summary>
+ public static partial class StopDebugLogResponseReflection {
+
+ #region Descriptor
+ /// <summary>File descriptor for StopDebugLogResponse.proto</summary>
+ public static pbr::FileDescriptor Descriptor {
+ get { return descriptor; }
+ }
+ private static pbr::FileDescriptor descriptor;
+
+ static StopDebugLogResponseReflection() {
+ byte[] descriptorData = global::System.Convert.FromBase64String(
+ string.Concat(
+ "ChpTdG9wRGVidWdMb2dSZXNwb25zZS5wcm90bxITVGFuZ28uUE1SLkRlYnVn",
+ "Z2luZyIWChRTdG9wRGVidWdMb2dSZXNwb25zZUIfCh1jb20udHdpbmUudGFu",
+ "Z28ucG1yLmRlYnVnZ2luZ2IGcHJvdG8z"));
+ descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
+ new pbr::FileDescriptor[] { },
+ new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Debugging.StopDebugLogResponse), global::Tango.PMR.Debugging.StopDebugLogResponse.Parser, null, null, null, null)
+ }));
+ }
+ #endregion
+
+ }
+ #region Messages
+ public sealed partial class StopDebugLogResponse : pb::IMessage<StopDebugLogResponse> {
+ private static readonly pb::MessageParser<StopDebugLogResponse> _parser = new pb::MessageParser<StopDebugLogResponse>(() => new StopDebugLogResponse());
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pb::MessageParser<StopDebugLogResponse> Parser { get { return _parser; } }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pbr::MessageDescriptor Descriptor {
+ get { return global::Tango.PMR.Debugging.StopDebugLogResponseReflection.Descriptor.MessageTypes[0]; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ pbr::MessageDescriptor pb::IMessage.Descriptor {
+ get { return Descriptor; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StopDebugLogResponse() {
+ OnConstruction();
+ }
+
+ partial void OnConstruction();
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StopDebugLogResponse(StopDebugLogResponse other) : this() {
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StopDebugLogResponse Clone() {
+ return new StopDebugLogResponse(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override bool Equals(object other) {
+ return Equals(other as StopDebugLogResponse);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public bool Equals(StopDebugLogResponse other) {
+ if (ReferenceEquals(other, null)) {
+ return false;
+ }
+ if (ReferenceEquals(other, this)) {
+ return true;
+ }
+ return true;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override int GetHashCode() {
+ int hash = 1;
+ return hash;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override string ToString() {
+ return pb::JsonFormatter.ToDiagnosticString(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void WriteTo(pb::CodedOutputStream output) {
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public int CalculateSize() {
+ int size = 0;
+ return size;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(StopDebugLogResponse other) {
+ if (other == null) {
+ return;
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(pb::CodedInputStream input) {
+ uint tag;
+ while ((tag = input.ReadTag()) != 0) {
+ switch(tag) {
+ default:
+ input.SkipLastField();
+ break;
+ }
+ }
+ }
+
+ }
+
+ #endregion
+
+}
+
+#endregion Designer generated code
diff --git a/Software/Visual_Studio/Tango.PMR/Debugging/DebugLogResponse.cs b/Software/Visual_Studio/Tango.PMR/Debugging/StartDebugLogResponse.cs
index b7112f262..107442cd2 100644
--- a/Software/Visual_Studio/Tango.PMR/Debugging/DebugLogResponse.cs
+++ b/Software/Visual_Studio/Tango.PMR/Debugging/StartDebugLogResponse.cs
@@ -1,5 +1,5 @@
// Generated by the protocol buffer compiler. DO NOT EDIT!
-// source: DebugLogResponse.proto
+// source: StartDebugLogResponse.proto
#pragma warning disable 1591, 0612, 3021
#region Designer generated code
@@ -9,44 +9,44 @@ using pbr = global::Google.Protobuf.Reflection;
using scg = global::System.Collections.Generic;
namespace Tango.PMR.Debugging {
- /// <summary>Holder for reflection information generated from DebugLogResponse.proto</summary>
- public static partial class DebugLogResponseReflection {
+ /// <summary>Holder for reflection information generated from StartDebugLogResponse.proto</summary>
+ public static partial class StartDebugLogResponseReflection {
#region Descriptor
/// <summary>File descriptor for DebugLogResponse.proto</summary>
public static pbr::FileDescriptor Descriptor {
get { return descriptor; }
}
private static pbr::FileDescriptor descriptor;
- static DebugLogResponseReflection() {
+ static StartDebugLogResponseReflection() {
byte[] descriptorData = global::System.Convert.FromBase64String(
string.Concat(
- "ChZEZWJ1Z0xvZ1Jlc3BvbnNlLnByb3RvEhNUYW5nby5QTVIuRGVidWdnaW5n",
- "GhZEZWJ1Z0xvZ0NhdGVnb3J5LnByb3RvIqQBChBEZWJ1Z0xvZ1Jlc3BvbnNl",
- "EjcKCENhdGVnb3J5GAEgASgOMiUuVGFuZ28uUE1SLkRlYnVnZ2luZy5EZWJ1",
- "Z0xvZ0NhdGVnb3J5EhAKCEZpbGVOYW1lGAIgASgJEhIKCkxpbmVOdW1iZXIY",
- "AyABKA0SDgoGRmlsdGVyGAQgASgNEg8KB01lc3NhZ2UYBSABKAkSEAoITW9k",
- "dWxlSWQYBiABKA1CHwodY29tLnR3aW5lLnRhbmdvLnBtci5kZWJ1Z2dpbmdi",
- "BnByb3RvMw=="));
+ "ChtTdGFydERlYnVnTG9nUmVzcG9uc2UucHJvdG8SE1RhbmdvLlBNUi5EZWJ1",
+ "Z2dpbmcaFkRlYnVnTG9nQ2F0ZWdvcnkucHJvdG8iqQEKFVN0YXJ0RGVidWdM",
+ "b2dSZXNwb25zZRI3CghDYXRlZ29yeRgBIAEoDjIlLlRhbmdvLlBNUi5EZWJ1",
+ "Z2dpbmcuRGVidWdMb2dDYXRlZ29yeRIQCghGaWxlTmFtZRgCIAEoCRISCgpM",
+ "aW5lTnVtYmVyGAMgASgNEg4KBkZpbHRlchgEIAEoDRIPCgdNZXNzYWdlGAUg",
+ "ASgJEhAKCE1vZHVsZUlkGAYgASgNQh8KHWNvbS50d2luZS50YW5nby5wbXIu",
+ "ZGVidWdnaW5nYgZwcm90bzM="));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { global::Tango.PMR.Debugging.DebugLogCategoryReflection.Descriptor, },
new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
- new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Debugging.DebugLogResponse), global::Tango.PMR.Debugging.DebugLogResponse.Parser, new[]{ "Category", "FileName", "LineNumber", "Filter", "Message", "ModuleId" }, null, null, null)
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Debugging.StartDebugLogResponse), global::Tango.PMR.Debugging.StartDebugLogResponse.Parser, new[]{ "Category", "FileName", "LineNumber", "Filter", "Message", "ModuleId" }, null, null, null)
}));
}
#endregion
}
#region Messages
- public sealed partial class DebugLogResponse : pb::IMessage<DebugLogResponse> {
- private static readonly pb::MessageParser<DebugLogResponse> _parser = new pb::MessageParser<DebugLogResponse>(() => new DebugLogResponse());
+ public sealed partial class StartDebugLogResponse : pb::IMessage<StartDebugLogResponse> {
+ private static readonly pb::MessageParser<StartDebugLogResponse> _parser = new pb::MessageParser<StartDebugLogResponse>(() => new StartDebugLogResponse());
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public static pb::MessageParser<DebugLogResponse> Parser { get { return _parser; } }
+ public static pb::MessageParser<StartDebugLogResponse> Parser { get { return _parser; } }
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public static pbr::MessageDescriptor Descriptor {
- get { return global::Tango.PMR.Debugging.DebugLogResponseReflection.Descriptor.MessageTypes[0]; }
+ get { return global::Tango.PMR.Debugging.StartDebugLogResponseReflection.Descriptor.MessageTypes[0]; }
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -55,14 +55,14 @@ namespace Tango.PMR.Debugging {
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public DebugLogResponse() {
+ public StartDebugLogResponse() {
OnConstruction();
}
partial void OnConstruction();
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public DebugLogResponse(DebugLogResponse other) : this() {
+ public StartDebugLogResponse(StartDebugLogResponse other) : this() {
category_ = other.category_;
fileName_ = other.fileName_;
lineNumber_ = other.lineNumber_;
@@ -72,8 +72,8 @@ namespace Tango.PMR.Debugging {
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public DebugLogResponse Clone() {
- return new DebugLogResponse(this);
+ public StartDebugLogResponse Clone() {
+ return new StartDebugLogResponse(this);
}
/// <summary>Field number for the "Category" field.</summary>
@@ -144,11 +144,11 @@ namespace Tango.PMR.Debugging {
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public override bool Equals(object other) {
- return Equals(other as DebugLogResponse);
+ return Equals(other as StartDebugLogResponse);
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public bool Equals(DebugLogResponse other) {
+ public bool Equals(StartDebugLogResponse other) {
if (ReferenceEquals(other, null)) {
return false;
}
@@ -234,7 +234,7 @@ namespace Tango.PMR.Debugging {
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public void MergeFrom(DebugLogResponse other) {
+ public void MergeFrom(StartDebugLogResponse other) {
if (other == null) {
return;
}
@@ -9,44 +9,44 @@ using pbr = global::Google.Protobuf.Reflection;
#region Descriptor
- /// <summary>File descriptor for DebugLogResponse.proto</summary>
+ /// <summary>File descriptor for StartDebugLogResponse.proto</summary>
public static pbr::FileDescriptor Descriptor {
get { return descriptor; }
diff --git a/Software/Visual_Studio/Tango.PMR/Debugging/DebugLogRequest.cs b/Software/Visual_Studio/Tango.PMR/Debugging/StopDebugLogRequest.cs
index a64d091d7..94ba8fafb 100644
--- a/Software/Visual_Studio/Tango.PMR/Debugging/DebugLogRequest.cs
+++ b/Software/Visual_Studio/Tango.PMR/Debugging/StopDebugLogRequest.cs
@@ -1,5 +1,5 @@
// Generated by the protocol buffer compiler. DO NOT EDIT!
-// source: DebugLogRequest.proto
+// source: StopDebugLogRequest.proto
#pragma warning disable 1591, 0612, 3021
#region Designer generated code
@@ -9,40 +9,40 @@ using pbr = global::Google.Protobuf.Reflection;
using scg = global::System.Collections.Generic;
namespace Tango.PMR.Debugging {
- /// <summary>Holder for reflection information generated from DebugLogRequest.proto</summary>
- public static partial class DebugLogRequestReflection {
+ /// <summary>Holder for reflection information generated from StopDebugLogRequest.proto</summary>
+ public static partial class StopDebugLogRequestReflection {
#region Descriptor
/// <summary>File descriptor for DebugLogRequest.proto</summary>
public static pbr::FileDescriptor Descriptor {
get { return descriptor; }
}
private static pbr::FileDescriptor descriptor;
- static DebugLogRequestReflection() {
+ static StopDebugLogRequestReflection() {
byte[] descriptorData = global::System.Convert.FromBase64String(
string.Concat(
- "ChVEZWJ1Z0xvZ1JlcXVlc3QucHJvdG8SE1RhbmdvLlBNUi5EZWJ1Z2dpbmci",
- "EQoPRGVidWdMb2dSZXF1ZXN0Qh8KHWNvbS50d2luZS50YW5nby5wbXIuZGVi",
- "dWdnaW5nYgZwcm90bzM="));
+ "ChlTdG9wRGVidWdMb2dSZXF1ZXN0LnByb3RvEhNUYW5nby5QTVIuRGVidWdn",
+ "aW5nIhUKE1N0b3BEZWJ1Z0xvZ1JlcXVlc3RCHwodY29tLnR3aW5lLnRhbmdv",
+ "LnBtci5kZWJ1Z2dpbmdiBnByb3RvMw=="));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { },
new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
- new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Debugging.DebugLogRequest), global::Tango.PMR.Debugging.DebugLogRequest.Parser, null, null, null, null)
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Debugging.StopDebugLogRequest), global::Tango.PMR.Debugging.StopDebugLogRequest.Parser, null, null, null, null)
}));
}
#endregion
}
#region Messages
- public sealed partial class DebugLogRequest : pb::IMessage<DebugLogRequest> {
- private static readonly pb::MessageParser<DebugLogRequest> _parser = new pb::MessageParser<DebugLogRequest>(() => new DebugLogRequest());
+ public sealed partial class StopDebugLogRequest : pb::IMessage<StopDebugLogRequest> {
+ private static readonly pb::MessageParser<StopDebugLogRequest> _parser = new pb::MessageParser<StopDebugLogRequest>(() => new StopDebugLogRequest());
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public static pb::MessageParser<DebugLogRequest> Parser { get { return _parser; } }
+ public static pb::MessageParser<StopDebugLogRequest> Parser { get { return _parser; } }
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public static pbr::MessageDescriptor Descriptor {
- get { return global::Tango.PMR.Debugging.DebugLogRequestReflection.Descriptor.MessageTypes[0]; }
+ get { return global::Tango.PMR.Debugging.StopDebugLogRequestReflection.Descriptor.MessageTypes[0]; }
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -51,28 +51,28 @@ namespace Tango.PMR.Debugging {
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public DebugLogRequest() {
+ public StopDebugLogRequest() {
OnConstruction();
}
partial void OnConstruction();
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public DebugLogRequest(DebugLogRequest other) : this() {
+ public StopDebugLogRequest(StopDebugLogRequest other) : this() {
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public DebugLogRequest Clone() {
- return new DebugLogRequest(this);
+ public StopDebugLogRequest Clone() {
+ return new StopDebugLogRequest(this);
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public override bool Equals(object other) {
- return Equals(other as DebugLogRequest);
+ return Equals(other as StopDebugLogRequest);
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public bool Equals(DebugLogRequest other) {
+ public bool Equals(StopDebugLogRequest other) {
if (ReferenceEquals(other, null)) {
return false;
}
@@ -104,7 +104,7 @@ namespace Tango.PMR.Debugging {
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public void MergeFrom(DebugLogRequest other) {
+ public void MergeFrom(StopDebugLogRequest other) {
if (other == null) {
return;
}
@@ -9,40 +9,40 @@ using pbr = global::Google.Protobuf.Reflection;
#region Descriptor
- /// <summary>File descriptor for DebugLogRequest.proto</summary>
+ /// <summary>File descriptor for StopDebugLogRequest.proto</summary>
public static pbr::FileDescriptor Descriptor {
get { return descriptor; }